@@ -53,7 +53,7 @@ namespace qdesigner_internal {
 // Richtext simplification filter helpers: Elements to be discarded
 static inline bool filterElement(QStringView name)
 {
-    return name != QStringLiteral("meta") && name != QStringLiteral("style");
+    return name != "meta"_L1 && name != "style"_L1;
 }
 
 // Richtext simplification filter helpers: Filter attributes of elements
@@ -65,15 +65,15 @@ static inline void filterAttributes(QStringView name,
         return;
 
      // No style attributes for <body>
-    if (name == QStringLiteral("body")) {
+    if (name == "body"_L1) {
         atts->clear();
         return;
     }
 
     // Clean out everything except 'align' for 'p'
-    if (name == QStringLiteral("p")) {
+    if (name == "p"_L1) {
         for (auto it = atts->begin(); it != atts->end(); ) {
-            if (it->name() == QStringLiteral("align")) {
+            if (it->name() == "align"_L1) {
                 ++it;
                 *paragraphAlignmentFound = true;
             } else {
@@ -145,6 +145,8 @@ public:
 
     QToolBar *createToolBar(QDesignerFormEditorInterface *core, QWidget *parent = nullptr);
 
+    QString text(Qt::TextFormat format) const;
+
     bool simplifyRichText() const      { return m_simplifyRichText; }
 
 public slots:
@@ -152,7 +154,6 @@ public slots:
     void setFontPointSize(double);
     void setText(const QString &text);
     void setSimplifyRichText(bool v);
-    QString text(Qt::TextFormat format) const;
 
 signals:
     void stateChanged();
@@ -177,17 +178,15 @@ public slots:
 
 private:
     RichTextEditor *m_editor;
-    Ui::AddLinkDialog *m_ui;
+    QT_PREPEND_NAMESPACE(Ui)::AddLinkDialog *m_ui;
 };
 
 AddLinkDialog::AddLinkDialog(RichTextEditor *editor, QWidget *parent) :
     QDialog(parent),
-    m_ui(new Ui::AddLinkDialog)
+    m_ui(new QT_PREPEND_NAMESPACE(Ui)::AddLinkDialog)
 {
     m_ui->setupUi(this);
 
-    setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
-
     m_editor = editor;
 }
 
@@ -216,12 +215,7 @@ void AddLinkDialog::accept()
     const QString url = m_ui->urlInput->text();
 
     if (!title.isEmpty()) {
-        QString html = QStringLiteral("<a href=\"");
-        html += url;
-        html += QStringLiteral("\">");
-        html += title;
-        html += QStringLiteral("</a>");
-
+        const QString html = "<a href=\""_L1 + url + "\">"_L1 + title + "</a>"_L1;
         m_editor->insertHtml(html);
     }
 
@@ -266,9 +260,9 @@ void HtmlTextEdit::contextMenuEvent(QContextMenuEvent *event)
     };
 
     for (const Entry &e : entries) {
-        QAction *entityAction = new QAction(QLatin1String(e.text),
+        QAction *entityAction = new QAction(QLatin1StringView(e.text),
                                             htmlMenu);
-        entityAction->setData(QLatin1String(e.entity));
+        entityAction->setData(QLatin1StringView(e.entity));
         htmlMenu->addAction(entityAction);
     }
 
@@ -480,12 +474,12 @@ RichTextEditorToolBar::RichTextEditorToolBar(QDesignerFormEditorInterface *core,
 
     // Insert hyperlink and image buttons
 
-    m_link_action->setIcon(createIconSet(QStringLiteral("textanchor.png")));
+    m_link_action->setIcon(createIconSet(u"textanchor.png"_s));
     m_link_action->setText(tr("Insert &Link"));
     connect(m_link_action, &QAction::triggered, this, &RichTextEditorToolBar::insertLink);
     addAction(m_link_action);
 
-    m_image_action->setIcon(createIconSet(QStringLiteral("insertimage.png")));
+    m_image_action->setIcon(createIconSet(u"insertimage.png"_s));
     m_image_action->setText(tr("Insert &Image"));
     connect(m_image_action, &QAction::triggered, this, &RichTextEditorToolBar::insertImage);
     addAction(m_image_action);
@@ -732,13 +726,12 @@ RichTextEditorDialog::RichTextEditorDialog(QDesignerFormEditorInterface *core, Q
     m_initialTab(RichTextIndex)
 {
     setWindowTitle(tr("Edit text"));
-    setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
 
     // Read settings
     const QDesignerSettingsInterface *settings = core->settingsManager();
-    const QString rootKey = QLatin1String(RichTextDialogGroupC) + QLatin1Char('/');
-    const QByteArray lastGeometry = settings->value(rootKey + QLatin1String(GeometryKeyC)).toByteArray();
-    const int initialTab = settings->value(rootKey + QLatin1String(TabKeyC), QVariant(m_initialTab)).toInt();
+    const QString rootKey = QLatin1StringView(RichTextDialogGroupC) + u'/';
+    const QByteArray lastGeometry = settings->value(rootKey + QLatin1StringView(GeometryKeyC)).toByteArray();
+    const int initialTab = settings->value(rootKey + QLatin1StringView(TabKeyC), QVariant(m_initialTab)).toInt();
     if (initialTab == RichTextIndex || initialTab == SourceIndex)
         m_initialTab = initialTab;
 
@@ -788,10 +781,10 @@ RichTextEditorDialog::RichTextEditorDialog(QDesignerFormEditorInterface *core, Q
 RichTextEditorDialog::~RichTextEditorDialog()
 {
     QDesignerSettingsInterface *settings = m_core->settingsManager();
-    settings->beginGroup(QLatin1String(RichTextDialogGroupC));
+    settings->beginGroup(QLatin1StringView(RichTextDialogGroupC));
 
-    settings->setValue(QLatin1String(GeometryKeyC), saveGeometry());
-    settings->setValue(QLatin1String(TabKeyC), m_tab_widget->currentIndex());
+    settings->setValue(QLatin1StringView(GeometryKeyC), saveGeometry());
+    settings->setValue(QLatin1StringView(TabKeyC), m_tab_widget->currentIndex());
     settings->endGroup();
 }
 
